==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ConverterHtmlType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p729701_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p909447_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;These settings are only used for HTML (e.g. websites) and HTML-based documents (e.g. e-mails).&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterHtmlType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterHtmlType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="templateData" type="{http://schema.webpdf.de/1.0/operation}TemplateDataType" minOccurs="0"/>
 *       </all>
 *       <attribute name="downloadImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="adjustFonts" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="baseURL" type="{http://www.w3.org/2001/XMLSchema}anyURI" default="" />
 *       <attribute name="useAsTemplate" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="useBackground" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterHtmlType", propOrder = {

})
public class ConverterHtmlType {

    protected TemplateDataType templateData;
    @XmlAttribute(name = "downloadImages")
    protected Boolean downloadImages;
    @XmlAttribute(name = "adjustFonts")
    protected Boolean adjustFonts;
    @XmlAttribute(name = "baseURL")
    @XmlSchemaType(name = "anyURI")
    protected String baseURL;
    @XmlAttribute(name = "useAsTemplate")
    protected Boolean useAsTemplate;
    @XmlAttribute(name = "useBackground")
    protected Boolean useBackground;

    /**
     * Gets the value of the templateData property.
     * 
     * @return
     *     possible object is
     *     {@link TemplateDataType }
     *     
     */
    public TemplateDataType getTemplateData() {
        return templateData;
    }

    /**
     * Sets the value of the templateData property.
     * 
     * @param value
     *     allowed object is
     *     {@link TemplateDataType }
     *     
     */
    public void setTemplateData(TemplateDataType value) {
        this.templateData = value;
    }

    public boolean isSetTemplateData() {
        return (this.templateData!= null);
    }

    /**
     * Gets the value of the downloadImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDownloadImages() {
        if (downloadImages == null) {
            return false;
        } else {
            return downloadImages;
        }
    }

    /**
     * Sets the value of the downloadImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDownloadImages(boolean value) {
        this.downloadImages = value;
    }

    public boolean isSetDownloadImages() {
        return (this.downloadImages!= null);
    }

    public void unsetDownloadImages() {
        this.downloadImages = null;
    }

    /**
     * Gets the value of the adjustFonts property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAdjustFonts() {
        if (adjustFonts == null) {
            return false;
        } else {
            return adjustFonts;
        }
    }

    /**
     * Sets the value of the adjustFonts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAdjustFonts(boolean value) {
        this.adjustFonts = value;
    }

    public boolean isSetAdjustFonts() {
        return (this.adjustFonts!= null);
    }

    public void unsetAdjustFonts() {
        this.adjustFonts = null;
    }

    /**
     * Gets the value of the baseURL property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBaseURL() {
        if (baseURL == null) {
            return "";
        } else {
            return baseURL;
        }
    }

    /**
     * Sets the value of the baseURL property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBaseURL(String value) {
        this.baseURL = value;
    }

    public boolean isSetBaseURL() {
        return (this.baseURL!= null);
    }

    /**
     * Gets the value of the useAsTemplate property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseAsTemplate() {
        if (useAsTemplate == null) {
            return false;
        } else {
            return useAsTemplate;
        }
    }

    /**
     * Sets the value of the useAsTemplate property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseAsTemplate(boolean value) {
        this.useAsTemplate = value;
    }

    public boolean isSetUseAsTemplate() {
        return (this.useAsTemplate!= null);
    }

    public void unsetUseAsTemplate() {
        this.useAsTemplate = null;
    }

    /**
     * Gets the value of the useBackground property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseBackground() {
        if (useBackground == null) {
            return true;
        } else {
            return useBackground;
        }
    }

    /**
     * Sets the value of the useBackground property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseBackground(boolean value) {
        this.useBackground = value;
    }

    public boolean isSetUseBackground() {
        return (this.useBackground!= null);
    }

    public void unsetUseBackground() {
        this.useBackground = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterHtmlType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p383362_="https://jakarta.ee/xml/ns/jaxb" xmlns:p837822_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;These settings are only used for HTML (e.g. websites) and HTML-based documents (e.g. e-mails).&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterHtmlType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterHtmlType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <all>
 *         <element name="templateData" type="{http://schema.webpdf.de/1.0/operation}TemplateDataType" minOccurs="0"/>
 *       </all>
 *       <attribute name="downloadImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="adjustFonts" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="baseURL" type="{http://www.w3.org/2001/XMLSchema}anyURI" default="" />
 *       <attribute name="useAsTemplate" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="useBackground" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterHtmlType", propOrder = {

})
public class ConverterHtmlType {

    protected TemplateDataType templateData;
    @XmlAttribute(name = "downloadImages")
    protected Boolean downloadImages;
    @XmlAttribute(name = "adjustFonts")
    protected Boolean adjustFonts;
    @XmlAttribute(name = "baseURL")
    @XmlSchemaType(name = "anyURI")
    protected String baseURL;
    @XmlAttribute(name = "useAsTemplate")
    protected Boolean useAsTemplate;
    @XmlAttribute(name = "useBackground")
    protected Boolean useBackground;

    /**
     * Gets the value of the templateData property.
     * 
     * @return
     *     possible object is
     *     {@link TemplateDataType }
     *     
     */
    public TemplateDataType getTemplateData() {
        return templateData;
    }

    /**
     * Sets the value of the templateData property.
     * 
     * @param value
     *     allowed object is
     *     {@link TemplateDataType }
     *     
     */
    public void setTemplateData(TemplateDataType value) {
        this.templateData = value;
    }

    public boolean isSetTemplateData() {
        return (this.templateData!= null);
    }

    /**
     * Gets the value of the downloadImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDownloadImages() {
        if (downloadImages == null) {
            return false;
        } else {
            return downloadImages;
        }
    }

    /**
     * Sets the value of the downloadImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDownloadImages(boolean value) {
        this.downloadImages = value;
    }

    public boolean isSetDownloadImages() {
        return (this.downloadImages!= null);
    }

    public void unsetDownloadImages() {
        this.downloadImages = null;
    }

    /**
     * Gets the value of the adjustFonts property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAdjustFonts() {
        if (adjustFonts == null) {
            return false;
        } else {
            return adjustFonts;
        }
    }

    /**
     * Sets the value of the adjustFonts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAdjustFonts(boolean value) {
        this.adjustFonts = value;
    }

    public boolean isSetAdjustFonts() {
        return (this.adjustFonts!= null);
    }

    public void unsetAdjustFonts() {
        this.adjustFonts = null;
    }

    /**
     * Gets the value of the baseURL property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBaseURL() {
        if (baseURL == null) {
            return "";
        } else {
            return baseURL;
        }
    }

    /**
     * Sets the value of the baseURL property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBaseURL(String value) {
        this.baseURL = value;
    }

    public boolean isSetBaseURL() {
        return (this.baseURL!= null);
    }

    /**
     * Gets the value of the useAsTemplate property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseAsTemplate() {
        if (useAsTemplate == null) {
            return false;
        } else {
            return useAsTemplate;
        }
    }

    /**
     * Sets the value of the useAsTemplate property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseAsTemplate(boolean value) {
        this.useAsTemplate = value;
    }

    public boolean isSetUseAsTemplate() {
        return (this.useAsTemplate!= null);
    }

    public void unsetUseAsTemplate() {
        this.useAsTemplate = null;
    }

    /**
     * Gets the value of the useBackground property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseBackground() {
        if (useBackground == null) {
            return true;
        } else {
            return useBackground;
        }
    }

    /**
     * Sets the value of the useBackground property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseBackground(boolean value) {
        this.useBackground = value;
    }

    public boolean isSetUseBackground() {
        return (this.useBackground!= null);
    }

    public void unsetUseBackground() {
        this.useBackground = null;
    }

}
